/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-accessibility-helpers--page#visually-hidden-elements)
 *
 * For elements that need to be hidden from sighted users and displayed to screen reader users.
 */
declare const visuallyHidden = "\n\tposition: absolute;\n\topacity: 0;\n\theight: 0;\n\twidth: 0;\n\ttop: 0;\n\tleft: 0;\n";
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-accessibility-helpers--page#focus-halo)
 *
 * Provides a clear focus state to support keyboard navigation.
 */
declare const focusHalo: string;
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-accessibility-helpers--page#description-id)
 *
 * Takes the ID of an element and generates a new ID. This should be set as the ID of an element that describes the first element. The generated ID should also be passed to the `aria-describedby` attribute on the first element.
 *
 * @param {string} id - ID of an element
 * @returns {string} ID of an element that describes the first element
 *
 * @example
 *		<form>
 *			<input id={id} type="text" aria-describedby={descriptionId(id)} />
 *			<p class="error" id={descriptionId(id)} />
 *		</form>
 */
declare const descriptionId: (id: string) => string;
declare const generateSourceId: () => string;

declare const transitions: {
    short: string;
    medium: string;
    long: string;
};

declare type Breakpoint = 'mobile' | 'mobileMedium' | 'mobileLandscape' | 'phablet' | 'tablet' | 'desktop' | 'leftCol' | 'wide';
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-media-queries--page#breakpoints) •
 * [Design System](https://theguardian.design/2a1e5182b/p/41be19-grids)
 */
declare const breakpoints: {
    readonly mobile: 320;
    readonly mobileMedium: 375;
    readonly mobileLandscape: 480;
    readonly phablet: 660;
    readonly tablet: 740;
    readonly desktop: 980;
    readonly leftCol: 1140;
    readonly wide: 1300;
};

declare type BreakpointMap = {
    [key in Breakpoint]: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-media-queries--page#from)
 *
 * @example
 *	const styles = css`
 *		${from.mobileLandscape} {
 *			padding: 0 20px;
 *		}
 * `;
 */
declare const from: BreakpointMap;
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-media-queries--page#until)
 *
 * @example
 *	const styles = css`
 *		${until.wide} {
 *			padding: 0 40px;
 *		}
 * `;
 */
declare const until: BreakpointMap;
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-media-queries--page#betweenand)
 *
 * @example
 *	const styles = css`
 *		${between.phablet.and.desktop} {
 *			padding: 0 32px;
 *		}
 * `;
 */
declare const between: {
    mobile: {
        and: {
            mobileMedium: string;
            mobileLandscape: string;
            phablet: string;
            tablet: string;
            desktop: string;
            leftCol: string;
            wide: string;
        };
    };
    mobileMedium: {
        and: {
            mobileLandscape: string;
            phablet: string;
            tablet: string;
            desktop: string;
            leftCol: string;
            wide: string;
        };
    };
    mobileLandscape: {
        and: {
            phablet: string;
            tablet: string;
            desktop: string;
            leftCol: string;
            wide: string;
        };
    };
    phablet: {
        and: {
            tablet: string;
            desktop: string;
            leftCol: string;
            wide: string;
        };
    };
    tablet: {
        and: {
            desktop: string;
            leftCol: string;
            wide: string;
        };
    };
    desktop: {
        and: {
            leftCol: string;
            wide: string;
        };
    };
    leftCol: {
        and: {
            wide: string;
        };
    };
};

/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/66411c)
 *
 * Our core brand colour – `brand[400]` – and extended brand colours
 */
declare const brand: {
    100: string;
    300: string;
    400: string;
    500: string;
    600: string;
    800: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/32d461)
 *
 * Our alternative brand colours
 */
declare const brandAlt: {
    200: string;
    300: string;
    400: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/70dd5c)
 *
 * Neutral colours
 */
declare const neutral: {
    0: string;
    7: string;
    10: string;
    20: string;
    46: string;
    60: string;
    86: string;
    93: string;
    97: string;
    100: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/98b901)
 *
 * Error colours
 */
declare const error: {
    400: string;
    500: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/82798f)
 *
 * Success colours
 */
declare const success: {
    400: string;
    500: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/97d77e)
 *
 * News colours
 */
declare const news: {
    100: string;
    200: string;
    300: string;
    400: string;
    500: string;
    550: string;
    600: string;
    800: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/0539ef)
 *
 * Opinion colours
 */
declare const opinion: {
    100: string;
    200: string;
    300: string;
    400: string;
    500: string;
    550: string;
    600: string;
    800: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/957a45)
 *
 * Sport colours
 */
declare const sport: {
    100: string;
    200: string;
    300: string;
    400: string;
    500: string;
    600: string;
    800: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/068eb2)
 *
 * Culture colours
 */
declare const culture: {
    50: string;
    100: string;
    200: string;
    300: string;
    350: string;
    400: string;
    500: string;
    600: string;
    700: string;
    800: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/2236b4)
 *
 * Lifestyle colours
 */
declare const lifestyle: {
    100: string;
    200: string;
    300: string;
    400: string;
    500: string;
    600: string;
    800: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/59b08c)
 *
 * Labs colours
 */
declare const labs: {
    200: string;
    300: string;
    400: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/31c634)
 *
 * Special report colours
 */
declare const specialReport: {
    100: string;
    200: string;
    300: string;
    400: string;
    450: string;
    500: string;
    700: string;
    800: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/188e86)
 *
 * Focus state colour
 */
declare const focus: {
    400: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/9280ee)
 *
 * Default theme background colours
 */
declare const background: {
    primary: string;
    secondary: string;
    inverse: string;
    ctaPrimary: string;
    ctaPrimaryHover: string;
    ctaSecondary: string;
    ctaSecondaryHover: string;
    ctaTertiaryHover: string;
    input: string;
    inputChecked: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/63cc10)
 *
 * Brand theme background colours
 */
declare const brandBackground: {
    primary: string;
    inputChecked: string;
    ctaPrimary: string;
    ctaPrimaryHover: string;
    ctaSecondary: string;
    ctaSecondaryHover: string;
    ctaTertiaryHover: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/743232)
 *
 * Alternative brand theme background colours
 */
declare const brandAltBackground: {
    primary: string;
    ctaPrimary: string;
    ctaPrimaryHover: string;
    ctaSecondary: string;
    ctaSecondaryHover: string;
    ctaTertiaryHover: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/69c92f)
 *
 * Default theme border colours
 */
declare const border: {
    primary: string;
    secondary: string;
    success: string;
    error: string;
    ctaTertiary: string;
    input: string;
    inputChecked: string;
    inputHover: string;
    inputActive: string;
    focusHalo: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/04883b)
 *
 * Brand theme border colours
 */
declare const brandBorder: {
    primary: string;
    secondary: string;
    success: string;
    error: string;
    ctaTertiary: string;
    input: string;
    inputChecked: string;
    inputHover: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/b/21c6cc)
 *
 * Alternative brand theme border colours
 */
declare const brandAltBorder: {
    ctaTertiary: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/593cc9)
 *
 * Default theme line colours
 */
declare const line: {
    primary: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/66455d)
 *
 * Brand theme line colours
 */
declare const brandLine: {
    primary: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/89955e)
 *
 * Alternative brand theme line colours
 */
declare const brandAltLine: {
    primary: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/85d3b0)
 *
 * Default theme text colours
 */
declare const text: {
    primary: string;
    supporting: string;
    success: string;
    error: string;
    ctaPrimary: string;
    ctaSecondary: string;
    ctaTertiary: string;
    anchorPrimary: string;
    anchorSecondary: string;
    userInput: string;
    inputLabel: string;
    inputError: string;
    inputLabelSupporting: string;
    inputChecked: string;
    inputHover: string;
    groupLabel: string;
    groupLabelSupporting: string;
    newsInverse: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/244480)
 *
 * Brand theme text colours
 */
declare const brandText: {
    primary: string;
    supporting: string;
    success: string;
    error: string;
    ctaPrimary: string;
    ctaSecondary: string;
    ctaTertiary: string;
    anchorPrimary: string;
    anchorPrimaryHover: string;
    userInput: string;
    inputLabel: string;
    inputLabelSupporting: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/11d5fd)
 *
 * Alternative brand theme text colours
 */
declare const brandAltText: {
    primary: string;
    supporting: string;
    ctaPrimary: string;
    ctaSecondary: string;
    ctaTertiary: string;
    anchorPrimary: string;
};

/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-size--page#global-size-values) •
 * [Design System](https://theguardian.design/2a1e5182b/p/24a3ec-size/t/329aef)
 *
 * May be used for call to action buttons and user input fields.
 */
declare const size: {
    readonly xsmall: 24;
    readonly small: 36;
    readonly medium: 44;
};
declare const iconSize: {
    readonly xsmall: 20;
    readonly small: 26;
    readonly medium: 30;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-size--page#tokens) •
 * [Design System](https://theguardian.design/2a1e5182b/p/24a3ec-size/t/329aef)
 *
 * Height tokens expressed in px
 *
 ** `height.ctaMedium`: call to action buttons and links
 ** `height.ctaSmall`: secondary calls to action
 ** `height.ctaXsmall`: calls to action where there is very limited space
 ** `height.inputMedium`: text input fields, radio and checkbox labels
 ** `height.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `height.iconMedium`
 ** `height.iconSmall`
 ** `height.iconXsmall`
 */
declare const height: {
    ctaMedium: 44;
    ctaSmall: 36;
    ctaXsmall: 24;
    inputMedium: 44;
    inputXsmall: 24;
    iconMedium: 30;
    iconSmall: 26;
    iconXsmall: 20;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-size--page#tokens) •
 * [Design System](https://theguardian.design/2a1e5182b/p/24a3ec-size/t/329aef)
 *
 * Height tokens expressed in rem
 *
 ** `remHeight.ctaMedium`: call to action buttons and links
 ** `remHeight.ctaSmall`: secondary calls to action
 ** `remHeight.ctaXsmall`: calls to action where there is very limited space
 ** `remHeight.inputMedium`: text input fields, radio and checkbox labels
 ** `remHeight.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `remHeight.iconMedium`
 ** `remHeight.iconSmall`
 ** `remHeight.iconXsmall`
 */
declare const remHeight: {
    ctaMedium: number;
    ctaSmall: number;
    ctaXsmall: number;
    inputMedium: number;
    inputXsmall: number;
    iconMedium: number;
    iconSmall: number;
    iconXsmall: number;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-size--page#tokens) •
 * [Design System](https://theguardian.design/2a1e5182b/p/00ddcb-tokens/t/797660)
 *
 * Width tokens expressed in px
 *
 ** `width.ctaMedium`: medium height call to action buttons and links
 ** `width.ctaSmall`: small height call to action buttons and links
 ** `width.ctaXsmall`: xsmall height call to action buttons and links
 ** `width.inputMedium`: text input fields, radio and checkbox labels
 ** `width.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `width.inputMedium`
 ** `width.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `width.iconMedium`
 ** `width.iconSmall`
 ** `width.iconXsmall`
 */
declare const width: {
    ctaMedium: 44;
    ctaSmall: 36;
    ctaXsmall: 24;
    inputXsmall: 24;
    iconMedium: 30;
    iconSmall: 26;
    iconXsmall: 20;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-size--page#tokens) •
 * [Design System](https://theguardian.design/2a1e5182b/p/00ddcb-tokens/t/797660)
 *
 * Width tokens expressed in rem
 *
 ** `remWidth.ctaMedium`: medium height call to action buttons and links
 ** `remWidth.ctaSmall`: small height call to action buttons and links
 ** `remWidth.ctaXsmall`: xsmall height call to action buttons and links
 ** `remWidth.inputMedium`: text input fields, radio and checkbox labels
 ** `remWidth.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `remWidth.inputMedium`
 ** `remWidth.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `remWidth.iconMedium`
 ** `remWidth.iconSmall`
 ** `remWidth.iconXsmall`
 */
declare const remWidth: {
    ctaMedium: number;
    ctaSmall: number;
    ctaXsmall: number;
    inputXsmall: number;
    iconMedium: number;
    iconSmall: number;
    iconXsmall: number;
};

/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-space--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/05f835-space)
 *
 * Can be applied to margin or padding properties, vertically or horizontally.
 *
 ** `space[1]` -> 4px
 ** `space[2]` -> 8px
 ** `space[3]` -> 12px
 ** `space[4]` -> 16px
 ** `space[5]` -> 20px
 ** `space[6]` -> 24px
 ** `space[9]` -> 36px
 ** `space[12]` -> 48px
 ** `space[24]` -> 96px
 */
declare const space: {
    readonly 1: 4;
    readonly 2: 8;
    readonly 3: 12;
    readonly 4: 16;
    readonly 5: 20;
    readonly 6: 24;
    readonly 9: 36;
    readonly 12: 48;
    readonly 24: 96;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-space--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/05f835-space)
 *
 * Can be applied to margin or padding properties, vertically or horizontally.
 *
 ** `remSpace[1]` -> 0.25rem
 ** `remSpace[2]` -> 0.5rem
 ** `remSpace[3]` -> 0.75rem
 ** `remSpace[4]` -> 1rem
 ** `remSpace[5]` -> 1.25rem
 ** `remSpace[6]` -> 1.5rem
 ** `remSpace[9]` -> 2.25rem
 ** `remSpace[12]` -> 3rem
 ** `remSpace[24]` -> 6rem
 */
declare const remSpace: {
    [K in keyof typeof space]: string;
};

declare type ScaleUnit = 'rem' | 'px';
declare type Category = 'titlepiece' | 'headline' | 'body' | 'textSans';
declare type LineHeight = 'tight' | 'regular' | 'loose';
declare type FontWeight = 'light' | 'regular' | 'medium' | 'bold';
declare type FontStyle = 'normal' | 'italic';
declare type FontWeightDefinition = {
    hasItalic: boolean;
};
declare type Option<A> = A | null;
declare type TypographyStyles = {
    fontFamily: string;
    fontSize: string | number;
    lineHeight: string | number;
    fontWeight?: number;
    fontStyle?: string;
};
declare type TypographySizes = {
    [key in string]: number;
};
interface TitlepieceSizes extends TypographySizes {
    small: number;
    medium: number;
    large: number;
}
interface HeadlineSizes extends TypographySizes {
    xxxsmall: number;
    xxsmall: number;
    xsmall: number;
    small: number;
    medium: number;
    large: number;
    xlarge: number;
}
interface BodySizes extends TypographySizes {
    small: number;
    medium: number;
}
interface TextSansSizes extends TypographySizes {
    xxsmall: number;
    xsmall: number;
    small: number;
    medium: number;
    large: number;
    xlarge: number;
    xxlarge: number;
    xxxlarge: number;
}
declare type Fs = (category: Category) => (level: string, { lineHeight, fontWeight, fontStyle, unit, }: {
    lineHeight: LineHeight;
    fontWeight: FontWeight;
    fontStyle: Option<FontStyle>;
    unit: ScaleUnit;
}) => TypographyStyles;
declare type FontScaleFunction = (options?: FontScaleArgs) => TypographyStyles;
declare type FontScaleFunctionStr = (options?: FontScaleArgs) => string;
interface FontScaleArgs {
    lineHeight?: LineHeight;
    fontWeight?: FontWeight;
    fontStyle?: FontStyle;
    unit?: ScaleUnit;
}

declare const titlepieceSizes: TitlepieceSizes;
declare const headlineSizes: HeadlineSizes;
declare const bodySizes: BodySizes;
declare const textSansSizes: TextSansSizes;
declare const remTitlepieceSizes: TitlepieceSizes;
declare const remHeadlineSizes: HeadlineSizes;
declare const remBodySizes: BodySizes;
declare const remTextSansSizes: TextSansSizes;
declare const fontMapping: {
    [cat in Category]: string;
};
declare const lineHeightMapping: {
    [lineHight in LineHeight]: number;
};
declare const fontWeightMapping: {
    [fontWeight in FontWeight]: number;
};

declare type TypographyApi<Sizes> = {
    [key in keyof Sizes]: FontScaleFunctionStr;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-typography--page#titlepiece) •
 * [Design System](https://theguardian.design/2a1e5182b/p/602314-typography/t/358767)
 *
 * ```
 * font-family: 'GT Guardian Titlepiece';
 * ```
 *
 * `titlepiece.small()` -> 42px
 *
 * `titlepiece.medium()` -> 50px
 *
 * `titlepiece.large()` -> 70px
 */
declare const titlepiece$1: TypographyApi<TitlepieceSizes>;
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-typography--page#headline) •
 * [Design System](https://theguardian.design/2a1e5182b/p/602314-typography/t/7310bd)
 *
 * ```
 * font-family: 'GH Guardian Headline';
 * ```
 *
 * `headline.xxxsmall()` -> 17px
 *
 * `headline.xxsmall()` -> 20px
 *
 * `headline.xsmall()` -> 24px
 *
 * `headline.small()` -> 28px
 *
 * `headline.medium()` -> 34px
 *
 * `headline.large()` -> 42px
 *
 * `headline.xlarge()` -> 50px
 */
declare const headline$1: TypographyApi<HeadlineSizes>;
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-typography--page#body) •
 * [Design System](https://theguardian.design/2a1e5182b/p/602314-typography/t/88cd8e)
 *
 * ```
 * font-family: 'GuardianTextEgyptian';
 * ```
 *
 * `body.small()` -> 15px
 *
 * `body.medium()` -> 17px
 */
declare const body$1: TypographyApi<BodySizes>;
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-typography--page#text-sans) •
 * [Design System](https://theguardian.design/2a1e5182b/p/602314-typography/t/076605)
 *
 * ```
 * font-family: 'GuardianTextSans';
 * ```
 *
 * `textSans.xxsmall()` -> 12px
 *
 * `textSans.xsmall()` -> 14px
 *
 * `textSans.small()` -> 15px
 *
 * `textSans.medium()` -> 17px
 *
 * `textSans.large()` -> 20px
 *
 * `textSans.xlarge()` -> 24px
 *
 * `textSans.xxlarge()` -> 28px
 *
 * `textSans.xxxlarge()` -> 34px
 */
declare const textSans$1: TypographyApi<TextSansSizes>;

declare type TitlepieceFunctions = {
    [key in keyof TitlepieceSizes]: FontScaleFunction;
};
declare const titlepiece: TitlepieceFunctions;
declare type HeadlineFunctions = {
    [key in keyof HeadlineSizes]: FontScaleFunction;
};
declare const headline: HeadlineFunctions;
declare type BodyFunctions = {
    [key in keyof BodySizes]: FontScaleFunction;
};
declare const body: BodyFunctions;
declare type TextSansFunctions = {
    [key in keyof TextSansSizes]: FontScaleFunction;
};
declare const textSans: TextSansFunctions;

declare const appearance = "(appearance: none) or (-webkit-appearance: none) or (-moz-appearance: none)";

declare const FocusStyleManager: {
    alwaysShowFocus: () => void;
    isActive: () => boolean;
    onlyShowFocusOnTabs: () => void;
};

declare const rootPixelFontSize = 16;
declare const pxToRem: (px: number) => number;

/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/source-v4-source-foundations-css-reset--page)
 *
 * `resets.resetCSS`: sensible default CSS rules to provide a base for a consistent environment across projects and browsers.
 */
declare const resets: {
    legend: string;
    fieldset: string;
    input: string;
    defaults: string;
    resetCSS: string;
};

declare const svgBackgroundImage: (svg: string) => string;

export { BodySizes, Breakpoint, Category, FocusStyleManager, FontScaleArgs, FontScaleFunction, FontScaleFunctionStr, FontStyle, FontWeight, FontWeightDefinition, Fs, HeadlineSizes, LineHeight, Option, ScaleUnit, TextSansSizes, TitlepieceSizes, TypographySizes, TypographyStyles, appearance, background, between, body$1 as body, body as bodyObjectStyles, bodySizes, border, brand, brandAlt, brandAltBackground, brandAltBorder, brandAltLine, brandAltText, brandBackground, brandBorder, brandLine, brandText, breakpoints, culture, descriptionId, error, focus, focusHalo, fontWeightMapping as fontWeights, fontMapping as fonts, from, generateSourceId, headline$1 as headline, headline as headlineObjectStyles, headlineSizes, height, iconSize, labs, lifestyle, line, lineHeightMapping as lineHeights, neutral, news, opinion, pxToRem, remBodySizes, remHeadlineSizes, remHeight, remSpace, remTextSansSizes, remTitlepieceSizes, remWidth, resets, rootPixelFontSize, size, space, specialReport, sport, success, svgBackgroundImage, text, textSans$1 as textSans, textSans as textSansObjectStyles, textSansSizes, titlepiece$1 as titlepiece, titlepiece as titlepieceObjectStyles, titlepieceSizes, transitions, until, visuallyHidden, width };
